# coding: utf-8

"""
    Regula Face SDK Web API

    <a href=\"https://regulaforensics.com/products/face-recognition-sdk/  \" target=\"_blank\">Regula Face SDK</a> is a cross-platform biometric verification solution for a digital identity verification process and image quality assurance. The SDK enables convenient and reliable face capture on the client side (mobile, web, and desktop) and further processing on the client or server side.   The Face SDK includes the following features:  * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-detection\" target=\"_blank\">Face detection and image quality assessment</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-comparison-11\" target=\"_blank\">Face match (1:1)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#face-identification-1n\" target=\"_blank\">Face search (1:N)</a> * <a href=\"https://docs.regulaforensics.com/develop/face-sdk/overview/introduction/#liveness-assessment\" target=\"_blank\">Liveness detection</a>  Here is the <a href=\"https://github.com/regulaforensics/FaceSDK-web-openapi  \" target=\"_blank\">OpenAPI specification on GitHub</a>.   ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 6.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class Crop(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'FaceImageQualityAlignType',
        'pad_color': 'RGB',
        'size': '[int]',
        'return_original_rect': 'bool',
    }

    attribute_map = {
        'type': 'type',
        'pad_color': 'padColor',
        'size': 'size',
        'return_original_rect': 'returnOriginalRect',
    }

    def __init__(self, type=None, pad_color=None, size=None, return_original_rect=None, local_vars_configuration=None):  # noqa: E501
        """Crop - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._pad_color = None
        self._size = None
        self._return_original_rect = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if pad_color is not None:
            self.pad_color = pad_color
        if size is not None:
            self.size = size
        if return_original_rect is not None:
            self.return_original_rect = return_original_rect

    @property
    def type(self):
        """Gets the type of this Crop.  # noqa: E501


        :return: The type of this Crop.  # noqa: E501
        :rtype: FaceImageQualityAlignType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Crop.


        :param type: The type of this Crop.  # noqa: E501
        :type type: FaceImageQualityAlignType
        """

        self._type = type

    @property
    def pad_color(self):
        """Gets the pad_color of this Crop.  # noqa: E501


        :return: The pad_color of this Crop.  # noqa: E501
        :rtype: RGB
        """
        return self._pad_color

    @pad_color.setter
    def pad_color(self, pad_color):
        """Sets the pad_color of this Crop.


        :param pad_color: The pad_color of this Crop.  # noqa: E501
        :type pad_color: RGB
        """

        self._pad_color = pad_color

    @property
    def size(self):
        """Gets the size of this Crop.  # noqa: E501

        The resize value in case `type` matches this value. If it doesn't, no resize is performed.  # noqa: E501

        :return: The size of this Crop.  # noqa: E501
        :rtype: [int]
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Crop.

        The resize value in case `type` matches this value. If it doesn't, no resize is performed.  # noqa: E501

        :param size: The size of this Crop.  # noqa: E501
        :type size: [int]
        """
        if (self.local_vars_configuration.client_side_validation and
                size is not None and len(size) > 2):
            raise ValueError("Invalid value for `size`, number of items must be less than or equal to `2`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                size is not None and len(size) < 2):
            raise ValueError("Invalid value for `size`, number of items must be greater than or equal to `2`")  # noqa: E501

        self._size = size

    @property
    def return_original_rect(self):
        """Gets the return_original_rect of this Crop.  # noqa: E501

        Whether to return the coordinates of the rectangle with the face in the original image prepared for the face crop.  # noqa: E501

        :return: The return_original_rect of this Crop.  # noqa: E501
        :rtype: bool
        """
        return self._return_original_rect

    @return_original_rect.setter
    def return_original_rect(self, return_original_rect):
        """Sets the return_original_rect of this Crop.

        Whether to return the coordinates of the rectangle with the face in the original image prepared for the face crop.  # noqa: E501

        :param return_original_rect: The return_original_rect of this Crop.  # noqa: E501
        :type return_original_rect: bool
        """

        self._return_original_rect = return_original_rect

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Crop):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Crop):
            return True

        return self.to_dict() != other.to_dict()




# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.diagnostics_api import DiagnosticsApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from regula.facesdk.webclient.gen.api.diagnostics_api import DiagnosticsApi
from regula.facesdk.webclient.gen.api.group_api import GroupApi
from regula.facesdk.webclient.gen.api.liveness_2_0_api import Liveness20Api
from regula.facesdk.webclient.gen.api.matching_api import MatchingApi
from regula.facesdk.webclient.gen.api.person_api import PersonApi
from regula.facesdk.webclient.gen.api.search_api import SearchApi



# coding: utf-8

"""
    Regula FaceSDK Web API

    Regula FaceSDK Web API # Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 4.1.3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from regula.facesdk.webclient.gen.api_client import ApiClient
from regula.facesdk.webclient.gen.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class LivenessApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def liveness_metadata(self, error_unknown, **kwargs):  # noqa: E501
        """Liveness 2.0 metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.liveness_metadata(error_unknown, async_req=True)
        >>> result = thread.get()

        :param error_unknown: ID of the current liveness transaction. (required)
        :type error_unknown: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        kwargs['_return_http_data_only'] = True
        return self.liveness_metadata_with_http_info(error_unknown, **kwargs)  # noqa: E501

    def liveness_metadata_with_http_info(self, error_unknown, **kwargs):  # noqa: E501
        """Liveness 2.0 metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.liveness_metadata_with_http_info(error_unknown, async_req=True)
        >>> result = thread.get()

        :param error_unknown: ID of the current liveness transaction. (required)
        :type error_unknown: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'error_unknown'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method liveness_metadata" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'error_unknown' is set
        if self.api_client.client_side_validation and ('error_unknown' not in local_var_params or  # noqa: E501
                                                        local_var_params['error_unknown'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `error_unknown` when calling `liveness_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'error_unknown' in local_var_params and local_var_params['error_unknown'] is not None:  # noqa: E501
            query_params.append(('', local_var_params['error_unknown']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json''application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/liveness/metadata', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def liveness_portrait(self, error_unknown, **kwargs):  # noqa: E501
        """Liveness 2.0 portrait  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.liveness_portrait(error_unknown, async_req=True)
        >>> result = thread.get()

        :param error_unknown: ID of the current liveness transaction. (required)
        :type error_unknown: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: file_type
        """
        kwargs['_return_http_data_only'] = True
        return self.liveness_portrait_with_http_info(error_unknown, **kwargs)  # noqa: E501

    def liveness_portrait_with_http_info(self, error_unknown, **kwargs):  # noqa: E501
        """Liveness 2.0 portrait  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.liveness_portrait_with_http_info(error_unknown, async_req=True)
        >>> result = thread.get()

        :param error_unknown: ID of the current liveness transaction. (required)
        :type error_unknown: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(file_type, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'error_unknown'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method liveness_portrait" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'error_unknown' is set
        if self.api_client.client_side_validation and ('error_unknown' not in local_var_params or  # noqa: E501
                                                        local_var_params['error_unknown'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `error_unknown` when calling `liveness_portrait`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'error_unknown' in local_var_params and local_var_params['error_unknown'] is not None:  # noqa: E501
            query_params.append(('', local_var_params['error_unknown']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/liveness/portrait', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file_type',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def liveness_video(self, error_unknown, **kwargs):  # noqa: E501
        """Liveness 2.0 video  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.liveness_video(error_unknown, async_req=True)
        >>> result = thread.get()

        :param error_unknown: ID of the current liveness transaction. (required)
        :type error_unknown: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: file_type
        """
        kwargs['_return_http_data_only'] = True
        return self.liveness_video_with_http_info(error_unknown, **kwargs)  # noqa: E501

    def liveness_video_with_http_info(self, error_unknown, **kwargs):  # noqa: E501
        """Liveness 2.0 video  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.liveness_video_with_http_info(error_unknown, async_req=True)
        >>> result = thread.get()

        :param error_unknown: ID of the current liveness transaction. (required)
        :type error_unknown: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(file_type, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'error_unknown'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method liveness_video" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'error_unknown' is set
        if self.api_client.client_side_validation and ('error_unknown' not in local_var_params or  # noqa: E501
                                                        local_var_params['error_unknown'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `error_unknown` when calling `liveness_video`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'error_unknown' in local_var_params and local_var_params['error_unknown'] is not None:  # noqa: E501
            query_params.append(('', local_var_params['error_unknown']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/liveness/video', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file_type',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    Regula FaceSDK Web API

    Regula FaceSDK Web API # Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 4.1.3
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class SearchRequestAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'limit': 'int',
        'threshold': 'float',
        'group_ids': '[int]',
    }

    attribute_map = {
        'limit': 'limit',
        'threshold': 'threshold',
        'group_ids': 'group_ids',
    }

    def __init__(self, limit=100, threshold=None, group_ids=None, local_vars_configuration=None):  # noqa: E501
        """SearchRequestAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._limit = None
        self._threshold = None
        self._group_ids = None
        self.discriminator = None

        if limit is not None:
            self.limit = limit
        if threshold is not None:
            self.threshold = threshold
        if group_ids is not None:
            self.group_ids = group_ids

    @property
    def limit(self):
        """Gets the limit of this SearchRequestAllOf.  # noqa: E501

        The number of returned Persons limit.  # noqa: E501

        :return: The limit of this SearchRequestAllOf.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this SearchRequestAllOf.

        The number of returned Persons limit.  # noqa: E501

        :param limit: The limit of this SearchRequestAllOf.  # noqa: E501
        :type limit: int
        """

        self._limit = limit

    @property
    def threshold(self):
        """Gets the threshold of this SearchRequestAllOf.  # noqa: E501

        Similarity threshold.  # noqa: E501

        :return: The threshold of this SearchRequestAllOf.  # noqa: E501
        :rtype: float
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """Sets the threshold of this SearchRequestAllOf.

        Similarity threshold.  # noqa: E501

        :param threshold: The threshold of this SearchRequestAllOf.  # noqa: E501
        :type threshold: float
        """

        self._threshold = threshold

    @property
    def group_ids(self):
        """Gets the group_ids of this SearchRequestAllOf.  # noqa: E501

        The IDs of the groups in which the search is performed.  # noqa: E501

        :return: The group_ids of this SearchRequestAllOf.  # noqa: E501
        :rtype: [int]
        """
        return self._group_ids

    @group_ids.setter
    def group_ids(self, group_ids):
        """Sets the group_ids of this SearchRequestAllOf.

        The IDs of the groups in which the search is performed.  # noqa: E501

        :param group_ids: The group_ids of this SearchRequestAllOf.  # noqa: E501
        :type group_ids: [int]
        """

        self._group_ids = group_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchRequestAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchRequestAllOf):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Regula FaceSDK Web API

    [Download OpenAPI specification](https://github.com/regulaforensics/FaceSDK-web-openapi) ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 6.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class PersonCreatedResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'int',
        'persons': '[SearchPerson]',
        'metadata': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
    }

    attribute_map = {
        'code': 'code',
        'persons': 'persons',
        'metadata': 'metadata',
    }

    def __init__(self, code=None, persons=None, metadata=None, local_vars_configuration=None):  # noqa: E501
        """PersonCreatedResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._persons = None
        self._metadata = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if persons is not None:
            self.persons = persons
        if metadata is not None:
            self.metadata = metadata

    @property
    def code(self):
        """Gets the code of this PersonCreatedResponse.  # noqa: E501

        Result code.  # noqa: E501

        :return: The code of this PersonCreatedResponse.  # noqa: E501
        :rtype: int
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this PersonCreatedResponse.

        Result code.  # noqa: E501

        :param code: The code of this PersonCreatedResponse.  # noqa: E501
        :type code: int
        """

        self._code = code

    @property
    def persons(self):
        """Gets the persons of this PersonCreatedResponse.  # noqa: E501

        Array of Person images.  # noqa: E501

        :return: The persons of this PersonCreatedResponse.  # noqa: E501
        :rtype: [SearchPerson]
        """
        return self._persons

    @persons.setter
    def persons(self, persons):
        """Sets the persons of this PersonCreatedResponse.

        Array of Person images.  # noqa: E501

        :param persons: The persons of this PersonCreatedResponse.  # noqa: E501
        :type persons: [SearchPerson]
        """

        self._persons = persons

    @property
    def metadata(self):
        """Gets the metadata of this PersonCreatedResponse.  # noqa: E501

        A free-form object containing person's extended attributes.  # noqa: E501

        :return: The metadata of this PersonCreatedResponse.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this PersonCreatedResponse.

        A free-form object containing person's extended attributes.  # noqa: E501

        :param metadata: The metadata of this PersonCreatedResponse.  # noqa: E501
        :type metadata: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PersonCreatedResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PersonCreatedResponse):
            return True

        return self.to_dict() != other.to_dict()
